@@ -2,17 +2,10 @@ package Mojolicious::Plugin::AssetPack::Che;
 use Mojo::Base 'Mojolicious::Plugin::AssetPack';
 use Mojolicious::Plugin::AssetPack::Util qw( checksum );
 use Mojo::URL;
-#~ use Mojo::Util qw(monkey_patch);
 
-BEGIN {
-  #~ # override for utf8
-  *Mojolicious::Plugin::AssetPack::Util::checksum = sub {
-  #~ monkey_patch 'Mojolicious::Plugin::AssetPack::Util', 'checksum'=>sub {
-    substr Mojo::Util::sha1_sum(Mojo::Util::encode('UTF-8', $_[0])), 0, $Mojolicious::Plugin::AssetPack::Util::SUM_LEN;
-  };
-}
 
 has [qw(app config)];
+has revision => sub { my $app = shift->app; $app->config('revision') // $app->config('version') // $app->config('версия') // ''; };
 
 sub register {
   my ($self, $app, $config) = @_;
@@ -34,6 +27,7 @@ sub register {
 
 sub process {# redefine for nested topics
   my ($self, $topic, @input) = @_;
+  utf8::encode($topic);
  
   $self->route unless $self->{route_added}++;
   return $self->_process_from_def($topic) unless @input;
@@ -43,6 +37,7 @@ sub process {# redefine for nested topics
   # CSS from?
   my $assets = Mojo::Collection->new;
   for my $url (@input) {
+    utf8::encode($url);
     if (my $nested = $self->processed($url)) {
       push @$assets, @$nested;
       next;
@@ -61,26 +56,27 @@ sub serve_cb {
   return sub {
     my $c = shift;
     my $checksum = $c->stash('checksum');
-    if (($c->req->headers->accept_encoding // '') =~ /gzip/i && (my $asset = $self->{by_checksum}{$checksum})) {
+    my $topic_checksum = checksum Mojo::Util::encode 'UTF-8', $c->stash('topic').$self->revision;
+    my $topic_checksum_gzip = checksum Mojo::Util::encode 'UTF-8', $c->stash('topic').$self->revision.'.gzip';
+    if ((my $asset = $self->{by_checksum}{$topic_checksum_gzip}) && ($c->req->headers->accept_encoding // '') =~ /gzip/i) {# 
       #~ warn "serve_cb", $c->dumper($asset);
-      my $cfconfig=$self->config->{CombineFile} || {};
-      my $checksum_gzip = checksum($asset->url.($self->app->config('version') // $self->app->config('версия') // '').'.gzip');
-      $asset = $self->{by_checksum}{$checksum_gzip}
-        and $c->res->headers->content_encoding('gzip')
-        and $self->store->serve_asset($c, $asset)
-        and return $c->rendered;
+      #~ my $cfconfig=$self->config->{CombineFile} || {};
+      #~ $self->app->log->debug($c->dumper($asset));
+      #~ my $checksum_gzip = checksum(Mojo::Util::encode 'UTF-8', $asset->url.$self->revision.'.gzip');#
+      #~ $asset = $self->{by_checksum}{$checksum_gzip}
+      $c->res->headers->content_encoding('gzip');
+      $self->store->serve_asset($c, $asset);
+      return $c->rendered;
+    } elsif ($asset = $self->{by_checksum}{$checksum} || $self->{by_checksum}{$topic_checksum}) {
+      $self->store->serve_asset($c, $asset);
+      return $c->rendered;
+      
     }
     Mojolicious::Plugin::AssetPack::_serve($c, @_);
   };
   
 }
 
-# override for utf8
-#~ sub Mojolicious::Plugin::AssetPack::Util::checksum {
-  #~ substr Mojo::Util::sha1_sum(Mojo::Util::encode('UTF-8', $_[0])), 0, $Mojolicious::Plugin::AssetPack::Util::SUM_LEN;
-#~ }
-
-
 
 =pod
 
@@ -108,11 +104,11 @@ Since version 1.28.
 
 =head1 VERSION
 
-Version 2.022 (test on base Mojolicious::Plugin::AssetPack v2.02)
+Version 2.023 (test on base Mojolicious::Plugin::AssetPack v2.02)
 
 =cut
 
-our $VERSION = '2.022';
+our $VERSION = '2.023';
 
 
 =head1 SYNOPSIS
